@@ -1,48 +1,52 @@
-from .layers import *
-from .utils import *
-from .positional_encoders import *
+from fastai.vision.models.xresnet import *
+
+from .ConvTranPlus import *
 from .explainability import *
 from .FCN import *
 from .FCNPlus import *
-from .TCN import *
-from .InceptionTime import *
-from .InceptionTimePlus import *
-from .MLP import *
 from .GatedTabTransformer import *
 from .gMLP import *
+from .HydraMultiRocketPlus import *
+from .HydraPlus import *
+from .InceptionTime import *
+from .InceptionTimePlus import *
+from .layers import *
+from .MINIROCKET import *
+from .MINIROCKET_Pytorch import *
+from .MINIROCKETPlus_Pytorch import *
+from .misc import *
+from .MLP import *
+from .MultiInputNet import *
+from .MultiRocketPlus import *
 from .mWDN import *
 from .OmniScaleCNN import *
+from .PatchTST import *
+from .positional_encoders import *
 from .ResCNN import *
 from .ResNet import *
 from .ResNetPlus import *
 from .RNN import *
-from .RNNAttention import *
-from .RNNPlus import *
 from .RNN_FCN import *
 from .RNN_FCNPlus import *
+from .RNNAttention import *
+from .RNNPlus import *
 from .ROCKET import *
-from .MINIROCKET import *
 from .ROCKET_Pytorch import *
-from .MINIROCKET_Pytorch import *
-from .MINIROCKETPlus_Pytorch import *
-from .MultiRocketPlus import *
+from .TabFusionTransformer import *
+from .TabModel import *
+from .TabTransformer import *
+from .TCN import *
 from .TransformerModel import *
 from .TransformerRNNPlus import *
+from .TSiTPlus import *
+from .TSPerceiver import *
+from .TSSequencerPlus import *
 from .TST import *
 from .TSTPlus import *
+from .utils import *
 from .XceptionTime import *
 from .XceptionTimePlus import *
 from .XCM import *
 from .XCMPlus import *
 from .XResNet1d import *
 from .XResNet1dPlus import *
-from fastai.vision.models.xresnet import *
-from .TabModel import *
-from .TabTransformer import *
-from .TabFusionTransformer import *
-from .TSPerceiver import *
-from .TSiTPlus import *
-from .TSSequencerPlus import *
-from .MultiInputNet import *
-from .PatchTST import *
-from .misc import *
\ No newline at end of file
